/// <reference types="react" />
interface ImageWithFadeinProps {
    src: string;
    width?: number;
    height?: number;
    scrollTo: number;
    imageTop: number;
    centerOffset?: number;
}
/**
 * @function ImageWithFadein
 * @desc renders a hidden image at a desired breakpoint (scrollTo) below the viewport,
 * and when scrolled down to, fixes it to the desired position (imageTop) and unhides it with a
 * ease-in animation. The image will hide again when scrolling up above the breakpoint.
 *
 * @param {string} props.src url of image
 * @param {number} props.height height of image
 * @param {number} props.width width of image
 * @param {number} props.scrollTo position in vh of image before coming into view. For best results, this should be greater than 100
 * @param {number} props.imageTop fixed position in vh of image when in view. For best results, this should be between 0 and 100
 * @param {number} [props.centerOffset=0] % off center (0) in vw with left offset - and right offset +
 */
declare const ImageWithFadein: ({ src, height, width, scrollTo, imageTop, centerOffset, }: ImageWithFadeinProps) => JSX.Element;

export { ImageWithFadein, ImageWithFadeinProps };
